@@ -442,7 +442,7 @@ class Purchase(
                     table.invoice_method,
                     where=(table.party == self.party.id)
                     & (table.invoice_party == invoice_party),
-                    order_by=table.id,
+                    order_by=table.id.desc,
                     limit=10)
                 cursor.execute(*subquery.select(
                         subquery.currency,
@@ -1574,8 +1574,9 @@ class Line(sequence_ordered(), ModelSQL, ModelView):
 
     def _get_invoice_not_line(self):
         'Return if the not line should be invoiced'
-        return (self.purchase.invoice_method == 'order'
-            and not self.invoice_lines)
+        return (
+            self.purchase.invoice_method == 'order'
+            and not self.purchase.invoices)
 
     def _get_invoice_line_quantity(self):
         'Return the quantity that should be invoiced'
